

.. _sphx_glr_auto_examples_plot_colourmap_pitfalls.py:



==================
Colormap pitfalls.
==================

Choosing the right colormap is important. A bad colormap like ``jet``
(standard in ROOT and matplotlib < 2.0) fools you into seeing structure
where there isn't any.




.. image:: /auto_examples/images/sphx_glr_plot_colourmap_pitfalls_001.png
    :align: center


.. rst-class:: sphx-glr-script-out

 Out::

    Loading style definitions from '/Users/tamasgal/Dev/km3pipe/km3pipe/kp-data/stylelib/km3pipe.mplstyle'




|


.. code-block:: python

    from __future__ import absolute_import, print_function, division

    import numpy as np
    import matplotlib.pyplot as plt
    from mpl_toolkits.axes_grid1 import make_axes_locatable
    import km3pipe.style
    km3pipe.style.use("km3pipe")

    x = np.linspace(-np.pi, np.pi, 300)
    xx, yy = np.meshgrid(x, x)
    z = np.cos(xx) + np.cos(yy)

    fig, axes = plt.subplots(2, 2)

    for ax, colourmap in zip(axes.flatten(),
                             ['gray', 'jet', 'cubehelix', 'cividis']):
        ax.set_title(colourmap)
        im = ax.imshow(z, cmap=plt.get_cmap(colourmap))
        divider = make_axes_locatable(ax)
        cax = divider.append_axes('right', size='7%', pad=0.05)
        cbar = plt.colorbar(im, cax=cax)

**Total running time of the script:** ( 0 minutes  0.151 seconds)



.. only :: html

 .. container:: sphx-glr-footer


  .. container:: sphx-glr-download

     :download:`Download Python source code: plot_colourmap_pitfalls.py <plot_colourmap_pitfalls.py>`



  .. container:: sphx-glr-download

     :download:`Download Jupyter notebook: plot_colourmap_pitfalls.ipynb <plot_colourmap_pitfalls.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
